<?php

namespace Drupal\Tests\viewsreference_filter\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test the Views Reference Field Filter.
 *
 * @group viewsreference_field
 */
class ViewsRefFilterTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * A user with permission to bypass access content.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'viewsreference',
    'viewsreference_filter',
    'viewsreference_filter_test',
    'node',
    'user',
    'block',
    'views_ui',
    'field_ui',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->adminUser = $this->drupalCreateUser([
      'access content',
      'bypass node access',
      'administer nodes',
      'administer content types',
      'administer node fields',
      'administer node display',
      'administer node form display',
    ]);
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Test that the filters values selected are applied to the view.
   *
   * @throws \Behat\Mink\Exception\ResponseTextException
   */
  public function testExposedFiltersApplication(): void {
    $this->drupalGet('node/add/test_content_type');
    $this->submitForm([
      'title[0][value]' => 'Test',
      'field_views_reference_field[0][target_id]' => 'test_view',
    ], 'Save');
    $this->submitForm([
      'title[0][value]' => 'Test',
      'field_views_reference_field[0][target_id]' => 'test_view',
      'field_views_reference_field[0][display_id]' => 'block_1',
    ], 'Save');
    $this->drupalGet('node/1');

    $this->drupalGet('node/1/edit');
    $this->submitForm([
      'title[0][value]' => 'Test',
      'field_views_reference_field[0][target_id]' => 'test_view',
      'field_views_reference_field[0][options][exposed_filters][status]' => '0',
    ], 'Save');

    $this->assertSession()->pageTextContains('No results');

    $this->drupalGet('node/1/edit');
    $this->submitForm([
      'title[0][value]' => 'Test',
      'field_views_reference_field[0][target_id]' => 'test_view',
      'field_views_reference_field[0][options][exposed_filters][status]' => '1',
    ], 'Save');

    $this->assertSession()->pageTextNotContains('No results');

  }

  /**
   * Test the visibility of the exposed filters and the user submitted input.
   *
   * @throws \Behat\Mink\Exception\ResponseTextException
   */
  public function testExposedFiltersVisibility():void {
    $this->drupalGet('node/add/test_content_type');
    $this->submitForm([
      'title[0][value]' => 'Test',
      'field_views_reference_field[0][target_id]' => 'test_view',
    ], 'Save');
    $this->submitForm([
      'title[0][value]' => 'Test',
      'field_views_reference_field[0][target_id]' => 'test_view',
      'field_views_reference_field[0][display_id]' => 'block_1',
    ], 'Save');
    $this->drupalGet('node/1');

    $this->assertSession()->pageTextNotContains('Published status');

    $this->drupalGet('node/1/edit');
    $this->submitForm([
      'title[0][value]' => 'Test',
      'field_views_reference_field[0][target_id]' => 'test_view',
      'field_views_reference_field[0][options][exposed_filters][vr_exposed_filters_visible]' => '1',
      'field_views_reference_field[0][options][exposed_filters][status]' => '0',
    ], 'Save');

    // Check the visibility of the filter.
    $this->assertSession()->pageTextContains('Published status');
    $this->assertSession()->pageTextContains('No results');

    // Check the user input for the exposed visible filters.
    $this->submitForm([
      'status' => '1',
    ], 'Apply');

    $this->assertSession()->pageTextNotContains('No results');

  }

}
